There's no jump.
- Remote mounts (needs `sshfs`, `rclone`)
- Familiar shortcuts (arrows, <kbd>~</kbd>, <kbd>-</kbd>, <kbd>@</kbd>), quick look-up
- `cd` on quit (*easy* shell integration)
- - Jump to next file on file open and selection
+ - Proceed to next file on file open and selection
- Search
- Instant filtering with *search-as-you-type*
- Regex (POSIX/PCRE) and string (default) filters
complete -c nnn -s g -d 'regex filters'
complete -c nnn -s H -d 'show hidden files'
complete -c nnn -s i -d 'show current file info'
-complete -c nnn -s J -d 'no auto-jump on select'
+complete -c nnn -s J -d 'no auto-advance on selection'
complete -c nnn -s K -d 'detect key collision'
complete -c nnn -s l -r -d 'lines to move per scroll'
complete -c nnn -s n -d 'start in type-to-nav mode'
'(-g)-g[regex filters]'
'(-H)-H[show hidden files]'
'(-i)-i[show current file info]'
- '(-J)-J[no auto-jump on select]'
+ '(-J)-J[no auto-advance on selection]'
'(-K)-K[detect key collision]'
'(-l)-l[lines to move per scroll]:val'
'(-n)-n[start in type-to-nav mode]'
show current file information in info bar (may be slow)
.Pp
.Fl J
- disable auto-jump on selection
+ disable auto-advance on selection
(eg. selecting an entry will no longer move cursor to the next entry)
.Pp
.Fl K
+ " -G always show git status\n"
" -H show hidden files\n"
" -i show current file info\n"
- " -J no auto-jump on selection\n"
+ " -J no auto-advance on selection\n"
@@ -8282,6 +8398,7 @@ static void cleanup(void)
fflush(stdout);
}
+ " -G always show git status\n"
" -H show hidden files\n"
" -i show current file info\n"
- " -J no auto-jump on selection\n"
+ " -J no auto-advance on selection\n"
@@ -8292,6 +8407,7 @@ static void cleanup(void)
fflush(stdout);
}
--- a/src/nnn.c
+++ b/src/nnn.c
@@ -372,7 +372,8 @@ typedef struct {
- uint_t stayonsel : 1; /* Disable auto-jump on select */
+ uint_t stayonsel : 1; /* Disable auto-advance on selection */
uint_t trash : 2; /* Trash method 0: rm -rf, 1: trash-cli, 2: gio trash */
uint_t uidgid : 1; /* Show owner and group info */
- uint_t reserved : 6; /* Adjust when adding/removing a field */
/* Non-persistent program-internal states (alphabeical order) */
typedef struct {
uint_t autofifo : 1; /* Auto-create NNN_FIFO */
- uint_t autonext : 1; /* Auto-jump on open */
+ uint_t autonext : 1; /* Auto-advance on file open */
uint_t dircolor : 1; /* Current status of dir color */
uint_t dirctx : 1; /* Show dirs in context color */
uint_t duinit : 1; /* Initialize disk usage */
uint_t runplugin : 1; /* Choose plugin mode */
uint_t selbm : 1; /* Select a bookmark from bookmarks directory */
uint_t selmode : 1; /* Set when selecting files */
- uint_t stayonsel : 1; /* Disable auto-jump on select */
+ uint_t stayonsel : 1; /* Disable auto-advance on selection */
uint_t trash : 2; /* Trash method 0: rm -rf, 1: trash-cli, 2: gio trash */
uint_t uidgid : 1; /* Show owner and group info */
uint_t reserved : 6; /* Adjust when adding/removing a field */
"9Lt h Parent%-12c~ ` @ - ~, /, start, prev\n"
"5Ret Rt l Open%-20c' First file/match\n"
"9g ^A Top%-21c. Toggle hidden\n"
- "9G ^E End%-20c^J Toggle auto-jump on open\n"
+ "9G ^E End%-20c^J Toggle auto-advance on open\n"
"8B (,) Book(mark)%-11cb ^/ Select bookmark\n"
"a1-4 Context%-11c(Sh)Tab Cycle/new context\n"
"62Esc ^Q Quit%-20cq Quit context\n"
" -g regex filters\n"
" -H show hidden files\n"
" -i show current file info\n"
- " -J no auto-jump on selection\n"
+ " -J no auto-advance on selection\n"
" -K detect key collision\n"
" -l val set scroll lines\n"
" -n type-to-nav mode\n"
{ 'u', SEL_UMOUNT },
/* Show help */
{ '?', SEL_HELP },
/* Toggle auto-jump on open */
{ CONTROL('J'), SEL_AUTONEXT },
/* Edit in EDITOR */
{ 'e', SEL_EDIT },
@@ -372,7 +372,8 @@ typedef struct {
/* Show help */
{ '?', SEL_HELP },
- /* Toggle auto-jump on open */
+ /* Toggle auto-advance on file open */
{ CONTROL('J'), SEL_AUTONEXT },
/* Edit in EDITOR */